@@ -6,6 +6,7 @@
 //!    * [Predefined Sources](#predefined-sources)
 //!    * [Key Convention](#key-convention)
 //!    * [Value Placeholder Parsing](#value-placeholder-parsing)
+//!    * [Attributes For Derive](#attributes-for-derive)
 //!
 //! ## About
 //! `salak` is a multi layered configuration loader with many predefined sources. Also it
@@ -47,10 +48,15 @@
 //!    * `random.u8`
 //!    * `random.u16`
 //!    * `random.u32`
+//!    * `random.u64`
+//!    * `random.u128`
+//!    * `random.usize`
 //!    * `random.i8`
 //!    * `random.i16`
 //!    * `random.i32`
 //!    * `random.i64`
+//!    * `random.i128`
+//!    * `random.isize`
 //! 2. Custom arguments source. [`SalakBuilder::set()`] can set a single kv,
 //! and [`SalakBuilder::set_args()`] can set a group of kvs.
 //! 3. System environment source. Implemented by [`system_environment`].
@@ -61,7 +67,7 @@
 //! #### Key Convention
 //! Key is used for search configuration from [`Environment`], normally it is represented by string.
 //! Key is a group of SubKey separated by dot(`.`), and SubKey is a name or a name followed by index.
-//! 1. SubKey Format (`[a-z][_a-z0-9]+(\[[0-9]+\])`)
+//! 1. SubKey Format (`[a-z][_a-z0-9]+(\[[0-9]+\])*`)
 //!    * `a`
 //!    * `a0`
 //!    * `a_b`
@@ -81,7 +87,15 @@
 //!    * `\$\{key\}` => Return `${key}`.
 //!    * `$`, `\`, `{`, `}` must use escape format.
 //!
-//!
+//! #### Attributes For Derive
+//! `salak` supports some attributes for automatically derive [`FromEnvironment`].
+//! All attributes have format `#[salak(..)]`, eg. `#[salak(default = "default value")]`.
+//! 1. Struct Header Attribute.
+//!    * `#[salak(prefix = "salak.application")]`, has this attr will auto implement [`PrefixedFromEnvironment`].
+//! 2. Struct Field Attribute.
+//!    * `#[salak(default = "value")]`, this attr can specify default value.
+//!    * `#[salak(name = "key")]`, this attr can specify property key, default convension is use field name.
+//!    * `#[salak(desc = "Field Description")]`, this attr can be describe this property.
 //!
 #![cfg_attr(docsrs, feature(doc_cfg))]
 #![warn(
@@ -106,21 +120,27 @@ mod derive;
 
 #[cfg(feature = "derive")]
 #[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
-pub use crate::derive::{AutoDeriveFromEnvironment, DefaultSourceFromEnvironment};
+pub use crate::derive::{
+    AutoDeriveFromEnvironment, DescribableEnvironment, KeyDesc, PrefixedFromEnvironment,
+};
 /// Auto derive [`FromEnvironment`] for struct.
 #[cfg(feature = "derive")]
 #[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
 pub use salak_derive::FromEnvironment;
 
-mod err;
+#[cfg(feature = "args")]
+#[cfg_attr(docsrs, doc(cfg(feature = "args")))]
+mod args;
+#[cfg(feature = "args")]
+#[cfg_attr(docsrs, doc(cfg(feature = "args")))]
+pub use crate::args::*;
 
+mod err;
 pub use crate::raw::*;
 mod raw;
-
 pub use crate::env::*;
-mod env;
-
 mod enums;
+mod env;
 
 pub use crate::enums::EnumProperty;
 pub use crate::err::{PropertyError, SalakParseError};
@@ -159,6 +179,11 @@ pub trait PropertySource {
     /// Check whether the [`PropertySource`] is empty.
     /// Empty source will not be ignored when register to registry.
     fn is_empty(&self) -> bool;
+
+    #[doc(hidden)]
+    fn list_source_names<'a>(&'a self, names: &mut Vec<&'a str>) {
+        names.push(self.name());
+    }
 }
 
 /// An environment for getting properties with mutiple [`PropertySource`]s, placeholder resolve and other features.
@@ -185,7 +210,7 @@ pub trait Environment {
     #[cfg(feature = "derive")]
     #[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
     /// Get config with predefined prefix.
-    fn get<T: DefaultSourceFromEnvironment>(&self) -> Result<T, PropertyError> {
+    fn get<T: PrefixedFromEnvironment>(&self) -> Result<T, PropertyError> {
         self.require::<T>(T::prefix())
     }
 }
@@ -201,4 +226,14 @@ pub trait FromEnvironment: Sized {
         val: Option<Property<'_>>,
         env: &'a impl Environment,
     ) -> Result<Self, PropertyError>;
+
+    #[cfg(feature = "derive")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
+    #[doc(hidden)]
+    fn key_desc<'a>(
+        key: &mut Key<'a>,
+        desc: &mut KeyDesc,
+        keys: &mut Vec<KeyDesc>,
+        env: &'a impl DescribableEnvironment,
+    );
 }
