@@ -136,7 +136,7 @@ fn parse_duration_from_str(du: &str) -> Result<Duration, PropertyError> {
                     last = Some('s');
                 }
                 i += multi * (c as u64 - '0' as u64);
-                multi = multi * 10;
+                multi *= 10;
             }
             _ => return Err(PropertyError::parse_fail("Invalid duration")),
         }
@@ -164,7 +164,7 @@ impl IsProperty for Duration {
     }
 }
 
-/// Sub key is partial [`Key`] having values with either `[_a-zA-Z0-9]+` or [`usize`].
+/// Sub key is partial [`Key`] having values with either `[a-z][_a-z0-9]*` or [`usize`].
 #[derive(Debug)]
 pub enum SubKey<'a> {
     /// Str sub key.
@@ -173,7 +173,7 @@ pub enum SubKey<'a> {
     I(usize),
 }
 
-/// Key has a string buffer, used for avoid allocate memory when parsing properties.
+/// Key with a string buffer, can be avoid allocating memory when parsing configuration.
 #[derive(Debug)]
 pub struct Key<'a> {
     buf: String,
@@ -208,6 +208,11 @@ impl<'a> Key<'a> {
         k
     }
 
+    #[allow(dead_code)]
+    pub(crate) fn as_generic(&self) -> String {
+        self.as_str().replace("[0]", "[*]")
+    }
+
     #[allow(dead_code)]
     pub(crate) fn iter(&self) -> std::slice::Iter<'_, SubKey<'_>> {
         self.key.iter()
@@ -220,6 +225,7 @@ impl<'a> Key<'a> {
         self.buf.as_str()
     }
 
+    #[doc(hidden)]
     pub(crate) fn push(&mut self, k: SubKey<'a>) {
         match &k {
             SubKey::S(v) => {
@@ -233,6 +239,7 @@ impl<'a> Key<'a> {
         self.key.push(k)
     }
 
+    #[doc(hidden)]
     pub(crate) fn pop(&mut self) {
         if let Some(v) = self.key.pop() {
             match v {
@@ -256,7 +263,7 @@ impl<'a> From<&'a str> for SubKey<'a> {
             u = &u[1..];
             let mut x = 0;
             for i in u.chars() {
-                if i >= '0' && i <= '9' {
+                if ('0'..='9').contains(&i) {
                     x = x * 10 + (i as usize) - ('0' as usize);
                 } else {
                     break;
@@ -595,6 +602,17 @@ mod tests {
                 i8: env.require_def(key, SubKey::S("i8"), None)?,
             })
         }
+
+        #[cfg(feature = "derive")]
+        #[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
+        fn key_desc<'a>(
+            key: &mut Key<'a>,
+            _: &mut KeyDesc,
+            keys: &mut Vec<KeyDesc>,
+            env: &'a impl DescribableEnvironment,
+        ) {
+            env.key_desc::<i8, &str>(key, "i8", None, None, None, keys);
+        }
     }
     #[test]
     fn config_test() {
